# ChemEco
              .......::::::: A General-Purpose Framework for Data Mining Without Coding :::::::.......

ChemEco is a flexible and versatile framework to compile a diverse collection of data mining and machine learning techniques from different sources.
It allows the user to build and run an arbitrary graph of operations via configuration files and graphical user interface (GUI).

Many customizable templates are provided in the GUI to share best practices in the data mining projects. Furthermore, these templates can be used for the
educational purposes, since they clearly show different elements and flow of data in a machine learning task.

## History
ChemEco was initially implemented to interface with Python libraries that are being developed in Hachmann group, i.e, ChemML and ChemLG.
The main focus of those packages is on the molecular and materials data-driven research.
That's why the name of all these packages express the word chem (chemistry).
However, we later used the code structure to interface with even more Python libraries or commercial software.
Thus, ChemEco now is able to carry out data mining and machine learning tasks on a broader range of domain applications.
